==> ViennaRNA-2.4.2.tar.gz: ViennaRNA-2.4.2/doc/html/group__domains__up.js <==
var group__domains__up =
[
    [ "unstructured_domains.h", "unstructured__domains_8h.html", null ],
    [ "vrna_unstructured_domain_s", "group__domains__up.html#structvrna__unstructured__domain__s", [
      [ "uniq_motif_count", "group__domains__up.html#ae17005ef8043aca2fc3864804cd5def6", null ],
      [ "uniq_motif_size", "group__domains__up.html#a2b484b0e19a47145db7055ada8b14159", null ],
      [ "motif_count", "group__domains__up.html#a5ad34148ea1d2e501f3e02029449546e", null ],
      [ "motif", "group__domains__up.html#af285436bbdea4436ad2cedec65d48c75", null ],
      [ "motif_size", "group__domains__up.html#a6a9f89ab7d147eb0ffd6cf8d77d178c0", null ],
      [ "motif_en", "group__domains__up.html#aae4f0a45419784fb7c244bce2781403d", null ],
      [ "motif_type", "group__domains__up.html#a3f0c026cced369ff176a66b2820f2057", null ],
      [ "prod_cb", "group__domains__up.html#ac2656d57130ac56e85212836482cbe80", null ],
      [ "exp_prod_cb", "group__domains__up.html#a181ae6ec67f77e68899ec6a0780f3e01", null ],
      [ "energy_cb", "group__domains__up.html#a1efba765dd4ea893dc8bd7362761f99b", null ],
      [ "exp_energy_cb", "group__domains__up.html#ad5aaa2530557880ae89e297f8f09aa55", null ],
      [ "data", "group__domains__up.html#a8802b1b0512999a9f35202031811ce17", null ],
      [ "free_data", "group__domains__up.html#a21b3084846902172858bc53f113d05a4", null ],
      [ "probs_add", "group__domains__up.html#a457b43dfab7f4321b5d7a84e5deea5d7", null ],
      [ "probs_get", "group__domains__up.html#a0b155283bccf65c5253f31e0211ae8ff", null ]
    ] ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_EXT_LOOP", "group__domains__up.html#gaac911374e86236a51bfd42e1f098eaba", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_HP_LOOP", "group__domains__up.html#ga23b610ea9564346c45cc1e2bbb62adf7", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_INT_LOOP", "group__domains__up.html#gac4a0feccd9654c149203200248c2716b", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_MB_LOOP", "group__domains__up.html#ga67b80796655e5227a4ed662bfbe398b0", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_MOTIF", "group__domains__up.html#gaab12b58d59be76446a9f76fad2fe624c", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_ALL_LOOPS", "group__domains__up.html#ga3c6be4cce70f1af9e885788856101699", null ],
    [ "vrna_ud_t", "group__domains__up.html#ga0009117b14d29143e8b18ab891f48c2d", null ],
    [ "vrna_callback_ud_energy", "group__domains__up.html#ga75825c57d0bfde4ae4f95c044260c5c3", null ],
    [ "vrna_callback_ud_exp_energy", "group__domains__up.html#ga861706f257ba993753464b823e65b86e", null ],
    [ "vrna_callback_ud_production", "group__domains__up.html#ga4fdfc02c1b660c07f2d887772f02a0a1", null ],
    [ "vrna_callback_ud_exp_production", "group__domains__up.html#ga33d78327dcd04c1ca5ab2887edc18c7b", null ],
    [ "vrna_callback_ud_probs_add", "group__domains__up.html#gab10498abc84fcaf336aca8f8d7d42eb2", null ],
    [ "vrna_callback_ud_probs_get", "group__domains__up.html#gaa10ba1b6f1e179ea84c5caca9cdaae67", null ],
    [ "vrna_ud_add_motif", "group__domains__up.html#gaec0c3313fb2951946614f920d289829a", null ],
    [ "vrna_ud_remove", "group__domains__up.html#gada59cb0c498b812eadd010811af3f2d4", null ],
    [ "vrna_ud_set_data", "group__domains__up.html#gac1f18c312b91d80089534a87d956e58b", null ],
    [ "vrna_ud_set_prod_rule_cb", "group__domains__up.html#ga745a99f0bc72898d54de16f6e538828a", null ],
    [ "vrna_ud_set_exp_prod_rule_cb", "group__domains__up.html#ga2fb1db2099da26c76247e1209ad4aa09", null ]
];

==> ViennaRNA-2.4.14.tar.gz: ViennaRNA-2.4.14/doc/html/group__domains__up.js <==
var group__domains__up =
[
    [ "unstructured_domains.h", "unstructured__domains_8h.html", null ],
    [ "vrna_unstructured_domain_s", "group__domains__up.html#structvrna__unstructured__domain__s", [
      [ "uniq_motif_count", "group__domains__up.html#ae17005ef8043aca2fc3864804cd5def6", null ],
      [ "uniq_motif_size", "group__domains__up.html#a2b484b0e19a47145db7055ada8b14159", null ],
      [ "motif_count", "group__domains__up.html#a5ad34148ea1d2e501f3e02029449546e", null ],
      [ "motif", "group__domains__up.html#af285436bbdea4436ad2cedec65d48c75", null ],
      [ "motif_name", "group__domains__up.html#ad061d55ef0b51d304c8dce88ebdbbf78", null ],
      [ "motif_size", "group__domains__up.html#a6a9f89ab7d147eb0ffd6cf8d77d178c0", null ],
      [ "motif_en", "group__domains__up.html#aae4f0a45419784fb7c244bce2781403d", null ],
      [ "motif_type", "group__domains__up.html#a3f0c026cced369ff176a66b2820f2057", null ],
      [ "prod_cb", "group__domains__up.html#ac2656d57130ac56e85212836482cbe80", null ],
      [ "exp_prod_cb", "group__domains__up.html#a181ae6ec67f77e68899ec6a0780f3e01", null ],
      [ "energy_cb", "group__domains__up.html#a1efba765dd4ea893dc8bd7362761f99b", null ],
      [ "exp_energy_cb", "group__domains__up.html#ad5aaa2530557880ae89e297f8f09aa55", null ],
      [ "data", "group__domains__up.html#a8802b1b0512999a9f35202031811ce17", null ],
      [ "free_data", "group__domains__up.html#a21b3084846902172858bc53f113d05a4", null ],
      [ "probs_add", "group__domains__up.html#a457b43dfab7f4321b5d7a84e5deea5d7", null ],
      [ "probs_get", "group__domains__up.html#a0b155283bccf65c5253f31e0211ae8ff", null ]
    ] ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_EXT_LOOP", "group__domains__up.html#gaac911374e86236a51bfd42e1f098eaba", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_HP_LOOP", "group__domains__up.html#ga23b610ea9564346c45cc1e2bbb62adf7", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_INT_LOOP", "group__domains__up.html#gac4a0feccd9654c149203200248c2716b", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_MB_LOOP", "group__domains__up.html#ga67b80796655e5227a4ed662bfbe398b0", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_MOTIF", "group__domains__up.html#gaab12b58d59be76446a9f76fad2fe624c", null ],
    [ "VRNA_UNSTRUCTURED_DOMAIN_ALL_LOOPS", "group__domains__up.html#ga3c6be4cce70f1af9e885788856101699", null ],
    [ "vrna_ud_t", "group__domains__up.html#ga0009117b14d29143e8b18ab891f48c2d", null ],
    [ "vrna_callback_ud_energy", "group__domains__up.html#ga75825c57d0bfde4ae4f95c044260c5c3", null ],
    [ "vrna_callback_ud_exp_energy", "group__domains__up.html#ga861706f257ba993753464b823e65b86e", null ],
    [ "vrna_callback_ud_production", "group__domains__up.html#ga4fdfc02c1b660c07f2d887772f02a0a1", null ],
    [ "vrna_callback_ud_exp_production", "group__domains__up.html#ga33d78327dcd04c1ca5ab2887edc18c7b", null ],
    [ "vrna_callback_ud_probs_add", "group__domains__up.html#gab10498abc84fcaf336aca8f8d7d42eb2", null ],
    [ "vrna_callback_ud_probs_get", "group__domains__up.html#gaa10ba1b6f1e179ea84c5caca9cdaae67", null ],
    [ "vrna_ud_motifs_centroid", "group__domains__up.html#ga2039caedf194c5edec794866986d95ec", null ],
    [ "vrna_ud_motifs_MEA", "group__domains__up.html#ga980126e9f350b64474b35f20fce2782c", null ],
    [ "vrna_ud_motifs_MFE", "group__domains__up.html#ga464d086264dd6f45089a65acec4e8c21", null ],
    [ "vrna_ud_add_motif", "group__domains__up.html#ga55f7de5ef5b7472b0eeab9296b57f671", null ],
    [ "vrna_ud_remove", "group__domains__up.html#gada59cb0c498b812eadd010811af3f2d4", null ],
    [ "vrna_ud_set_data", "group__domains__up.html#gac1f18c312b91d80089534a87d956e58b", null ],
    [ "vrna_ud_set_prod_rule_cb", "group__domains__up.html#ga745a99f0bc72898d54de16f6e538828a", null ],
    [ "vrna_ud_set_exp_prod_rule_cb", "group__domains__up.html#ga2fb1db2099da26c76247e1209ad4aa09", null ]
];
